##  Mandatory Attributes and Quality Seal
When mandatory attributes are defined for a fact sheet type, the quality seal of a fact sheet can be approved by the responsible or accountable subscribers only when all mandatory attributes are populated.
**Note**
Fact sheets whose quality seal was approved before enabling mandatory attributes will remain approved, even if their mandatory attributes are not filled.
Before the fact sheet is approved, the values of mandatory fields can be edited or even removed to leave them empty. Once a fact sheet is approved, you can still edit the value of the mandatory field, but it is not possible to remove the value of the mandatory field and leave it empty. You can do it only after setting the fact sheet quality seal back to Draft.
Similarly, the last remaining value of mandatory relations, tags, and subscribers can be edited but can not be removed from an approved fact sheet without setting the fact sheet quality seal back to Draft.
To learn more about quality seals and quality seal states, see [Quality Seal](https://help.sap.com/docs/leanix/ea/quality-seal?locale=en-US&state=PRODUCTION&version=CLOUD "Quality seal ensures data integrity by assigning approval responsibility to accountable and responsible subscribers of fact sheets. When broken, it prompts verification and approval of fact sheet information.").
